@@ -3,7 +3,7 @@ package Egg;
 # Copyright 2006 Bee Flag, Corp. All Rights Reserved.
 # Masatoshi Mizuno E<lt>mizunoE<64>bomcity.comE<gt>
 #
-# $Id: Egg.pm 35 2006-12-14 08:21:05Z lushe $
+# $Id: Egg.pm 50 2006-12-15 08:11:06Z lushe $
 #
 use strict;
 use warnings;
@@ -13,9 +13,9 @@ use NEXT;
 use Egg::Response;
 use base qw/Egg::Engine Class::Accessor::Fast/;
 
-our $VERSION= '0.11';
+our $VERSION= '0.13';
 
-__PACKAGE__->mk_accessors( qw/view snip stash request response/ );
+__PACKAGE__->mk_accessors( qw/view snip request response/ );
 
 BEGIN {
 	my $count;
@@ -109,7 +109,7 @@ sub import {
 	# dispatch is loaded.
 		my $d_class;
 		if ($d_class= $ENV{"$firstName\_DISPATCHER"}) {
-			$flags->{D_CLASS} = "Egg::D::$d_class";
+			$d_class= $flags->{D_CLASS}= "Egg::D::$d_class";
 		} elsif ($d_class= $ENV{"$firstName\_CUSTOM_DISPATCHER"}) {
 			$flags->{D_CLASS} = $d_class;
 		} elsif ($d_class= $ENV{"$firstName\_UNLOAD_DISPATCHER"}) {
@@ -206,6 +206,13 @@ sub new {
 	$e->view ( $view_class->new($e) );
 	$e;
 }
+sub stash {
+	my $e= shift;
+	return $e->{stash} if @_< 1;
+	my $key= shift;
+	$e->{stash}{$key}= shift if @_> 0;
+	$e->{stash}{$key};
+}
 sub dispatch {
 	my $e= shift;
 	return "$e->{namespace}::D::$_[0]" if @_;
@@ -353,6 +360,12 @@ The ARRAY reference into which the request passing is divided by/is returned.
 
 It is a preservation place to share data.
 
+=head2 $e->stash([KEY], [VALUE]);
+
+When [KEY] is given, the value of $e->stash->{[KEY]} is returned.
+
+When [VALUE] is given, the value is set in $e->stash->{[KEY]}.
+
 =head2 $e->finished([RESPONSE STATUS CODE]);
 
 It reports on the completion of processing.
