@@ -3,11 +3,14 @@ package Egg::Config;
 # Copyright 2006 Bee Flag, Corp. All Rights Reserved.
 # Masatoshi Mizuno E<lt>mizunoE<64>bomcity.comE<gt>
 #
-# $Id$
+# $Id: Config.pm 34 2006-12-14 08:17:52Z lushe $
 #
 use strict;
+use warnings;
 use base qw/Egg::Appli/;
 
+our $VERSION= '0.01';
+
 sub setup {
 	my($class, $e, $config, $name)= @_;
 	if ($config) {
